@@ -16,8 +16,6 @@ sub dispatch {
         or croak "Invalid controller '$to'";
 
     my $controller = $app->_clone($controller_class);
-
-    $controller->before_dispatch($action);
     return $controller->$action(@{ $match->param });
 }
 
@@ -61,7 +59,7 @@ Kelp::Routes::Controller - Routes and controller for Kelp
     package MyApp::Controller::Users;
     use Kelp::Base 'MyApp::Controller';
 
-    sub read {
+    my read {
         my $self = shift;   # $self is an instance of 'MyApp::Controller::Users'
         ...
     }
@@ -80,4 +78,3 @@ functionality.
 
 
 =cut
-
