@@ -1,6 +1,7 @@
 package MyApp;
 use Kelp::Base 'Kelp';
 use MyApp::Response;
+use UtilPackage;
 
 sub before_finalize {
     my $self = shift;
@@ -23,4 +24,12 @@ sub build {
     $r->add("/blessed", "blessed");
 }
 
+sub blessed {
+    my ( $self ) = @_;
+
+    $self->template('home');
+}
+
+sub check_util_fun { path; }
+
 1;
